summaryrefslogtreecommitdiffstats
path: root/src/profileengine
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2014-03-02 20:05:33 +0100
committerSlávek Banko <slavek.banko@axis.cz>2014-03-02 20:05:33 +0100
commit722ce1efbac31c61b1d4b13f7e075c9f311e3e73 (patch)
treedb1b6b28566e5fe9accb4a688f7257673cecb080 /src/profileengine
parentafb74575caf7dd8ccb6c235b1c8d788e320c19da (diff)
downloadtdevelop-722ce1efbac31c61b1d4b13f7e075c9f311e3e73.tar.gz
tdevelop-722ce1efbac31c61b1d4b13f7e075c9f311e3e73.zip
Finish renaming tdevelop components
Diffstat (limited to 'src/profileengine')
-rw-r--r--src/profileengine/editor/CMakeLists.txt4
-rw-r--r--src/profileengine/editor/Makefile.am8
-rw-r--r--src/profileengine/editor/main.cpp2
-rw-r--r--src/profileengine/lib/Makefile.am6
-rw-r--r--src/profileengine/lib/profileengine.cpp2
-rw-r--r--src/profileengine/lib/profileengine.h16
6 files changed, 19 insertions, 19 deletions
diff --git a/src/profileengine/editor/CMakeLists.txt b/src/profileengine/editor/CMakeLists.txt
index cfd7c59c..443da696 100644
--- a/src/profileengine/editor/CMakeLists.txt
+++ b/src/profileengine/editor/CMakeLists.txt
@@ -21,9 +21,9 @@ link_directories(
)
-##### kdevprofileeditor (executable) ############
+##### tdevprofileeditor (executable) ############
-tde_add_executable( kdevprofileeditor
+tde_add_executable( tdevprofileeditor
SOURCES main.cpp
LINK profileeditor-static profileengine-shared tdeio-shared
DESTINATION ${BIN_INSTALL_DIR}
diff --git a/src/profileengine/editor/Makefile.am b/src/profileengine/editor/Makefile.am
index 26f69be6..fae89b48 100644
--- a/src/profileengine/editor/Makefile.am
+++ b/src/profileengine/editor/Makefile.am
@@ -12,11 +12,11 @@ libprofileeditor_la_SOURCES = profileeditorbase.ui profileeditor.cpp \
noinst_HEADERS = profileeditor.h
-bin_PROGRAMS = kdevprofileeditor
-kdevprofileeditor_LDFLAGS = $(all_libraries)
-kdevprofileeditor_LDADD = \
+bin_PROGRAMS = tdevprofileeditor
+tdevprofileeditor_LDFLAGS = $(all_libraries)
+tdevprofileeditor_LDADD = \
$(top_builddir)/src/profileengine/lib/libprofileengine.la libprofileeditor.la \
$(LIB_TDEUI) $(LIB_TDEIO)
-kdevprofileeditor_SOURCES = main.cpp
+tdevprofileeditor_SOURCES = main.cpp
diff --git a/src/profileengine/editor/main.cpp b/src/profileengine/editor/main.cpp
index 46d128f3..68e942d7 100644
--- a/src/profileengine/editor/main.cpp
+++ b/src/profileengine/editor/main.cpp
@@ -30,7 +30,7 @@ static TDECmdLineOptions options[] =
int main(int argc, char **argv)
{
- TDEAboutData about("kdevprofileeditor", I18N_NOOP("TDevelop Profile Editor"), "1", "",
+ TDEAboutData about("tdevprofileeditor", I18N_NOOP("TDevelop Profile Editor"), "1", "",
TDEAboutData::License_GPL, I18N_NOOP("(c) 2004, The KDevelop Developers"), 0, 0, "");
about.addAuthor("Alexander Dymo", 0, "adymo@kdevelop.org");
TDECmdLineArgs::init(argc, argv, &about);
diff --git a/src/profileengine/lib/Makefile.am b/src/profileengine/lib/Makefile.am
index 08b6e7ad..66b1f159 100644
--- a/src/profileengine/lib/Makefile.am
+++ b/src/profileengine/lib/Makefile.am
@@ -10,7 +10,7 @@ libprofileengine_la_SOURCES = profileengine.cpp profile.cpp
profileincludedir = $(includedir)/tdevelop/shell/profileengine
profileinclude_HEADERS = profileengine.h profile.h
-DOXYGEN_REFERENCES = dcop interfaces tdecore tdefx tdeui tdehtml tdemdi tdeio kjs tdeparts tdeutils kdevutil kdevinterfaces
-DOXYGEN_PROJECTNAME = KDevelop Shell Profiles Library
-DOXYGEN_DOCDIRPREFIX = kdevprofiles
+DOXYGEN_REFERENCES = dcop interfaces tdecore tdefx tdeui tdehtml tdemdi tdeio kjs tdeparts tdeutils tdevutil tdevinterfaces
+DOXYGEN_PROJECTNAME = TDevelop Shell Profiles Library
+DOXYGEN_DOCDIRPREFIX = tdevprofiles
include ../../../Doxyfile.am
diff --git a/src/profileengine/lib/profileengine.cpp b/src/profileengine/lib/profileengine.cpp
index fd4d06fa..8678732e 100644
--- a/src/profileengine/lib/profileengine.cpp
+++ b/src/profileengine/lib/profileengine.cpp
@@ -25,7 +25,7 @@
#include <tdeglobal.h>
#include <kstandarddirs.h>
-#include <kdevplugin.h>
+#include <tdevplugin.h>
ProfileEngine::ProfileEngine()
{
diff --git a/src/profileengine/lib/profileengine.h b/src/profileengine/lib/profileengine.h
index 36d85697..d630f576 100644
--- a/src/profileengine/lib/profileengine.h
+++ b/src/profileengine/lib/profileengine.h
@@ -61,27 +61,27 @@ public:
/**
Profile engine.
-- Uses KDevelop profiles to form lists of plugin offers;
+- Uses TDevelop profiles to form lists of plugin offers;
- Provides means of managing profiles;
- Provides means to access the resources provided by a profile.
-KDevelop profiles form a tree with a root profile named "KDevelop".
+TDevelop profiles form a tree with a root profile named "TDevelop".
For example, such profiles tree can look as:
@code
-KDevelop
+TDevelop
- IDE
- CompiledLanguageIDE
- AdaIDE
- CandCppIDE
- CIDE
- CppIDE
- - KDECppIDE
+ - TDECppIDE
- FortranIDE
...
- DatabaseIDE
- ScriptingLanguageIDE
..
-- KDevAssistant
+- TDevAssistant
@endcode
To manage a tree of profiles, use @ref ProfileEngine::walkProfiles methods.
*/
@@ -92,7 +92,7 @@ public:
/**Type of the plugin offer. Engine will usually find profiles and return offers
of selected type.
- @sa KDevPlugin class documentation for more information of plugin types.*/
+ @sa TDevPlugin class documentation for more information of plugin types.*/
enum OfferType {
Global /**<Global plugins.*/,
Project /**<Project plugins.*/,
@@ -137,8 +137,8 @@ public:
void diffProfiles(OfferType offerType, const TQString &profile1, const TQString &profile2,
TQStringList &unload, TDETrader::OfferList &load);
- /**@return The root profile. Root profile is always named "KDevelop" and it
- defines an empty list of plugins. Applications built on KDevelop platform
+ /**@return The root profile. Root profile is always named "TDevelop" and it
+ defines an empty list of plugins. Applications built on TDevelop platform
will define nested profiles.*/
Profile *rootProfile() const { return m_rootProfile; }
/**Finds a profile with given name.